@@ -15,6 +15,7 @@ handled.
 Author: Jacob Seiler
 """
 
+import logging
 import warnings
 
 import numpy as np
@@ -22,6 +23,8 @@ from scipy import stats
 
 from sage_analysis.model import Model
 
+logger = logging.getLogger(__name__)
+
 
 def calc_SMF(
     model: Model,
@@ -256,7 +259,7 @@ def calc_metallicity(model, gals, snapshot: int):
     )
 
 
-def calc_bh_bulge(model, gals, snapshot: int):
+def calc_bh_bulge(model, gals, snapshot: int) -> None:
     """
     Calculates the black hole mass as a function of bulge mass.
 
@@ -273,6 +276,12 @@ def calc_bh_bulge(model, gals, snapshot: int):
 
     # Only care about galaxies that have appreciable masses.
     my_gals = np.where((gals["BulgeMass"][:] > 0.01) & (gals["BlackHoleMass"][:] > 0.00001))[0]
+    if not len(my_gals):
+        logger.info(
+            "Could not find any galaxies with bulge mass >1e8 Msun and black hole mass >1e5 Msun when trying to "
+            "compute black hole bulge relationship."
+        )
+        return
 
     # Select a random subset of galaxies (if necessary).
     my_gals = model.select_random_galaxy_indices(
